@@ -51,8 +51,10 @@ interfaces.IB.prototype.ROYALE_CLASS_INFO = { names: [{ name: 'IB', qName: 'inte
  * @return {Object.<string, Function>}
  */
 interfaces.IB.prototype.ROYALE_REFLECTION_INFO = function () {
-  return {
-    accessors: function () {return {};},
-    methods: function () {return {};}
-  };
+  return {};
 };
+/**
+ * @const
+ * @type {number}
+ */
+interfaces.IB.prototype.ROYALE_COMPILE_FLAGS = 9;
